==> openGion7.0.1.4_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE50S.sql <==
/****************************************************************************/
/* GE50 ( 帳票要求ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2017/07/18 08:42:12                                            */
/****************************************************************************/

CREATE TABLE GE50 (
   SYSTEM_ID    varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , YKNO         INTEGER             DEFAULT 0   NOT NULL            /*  20 要求NO       */
 , GROUPID      varchar (  10 )                                     /*  30 ｸﾞﾙｰﾌﾟID     */
 , LISTID       varchar (  10 )                 NOT NULL            /*  40 帳票ID       */
 , JOKEN        varchar (  20 )                 NOT NULL            /*  50 振分条件     */
 , FGKAN        varchar (   1 )                 NOT NULL            /*  60 完成ﾌﾗｸﾞ     */
 , OUT_DIR      varchar ( 100 )                                     /*  70 出力ﾌｧｲﾙDIR  */
 , OUT_FILE     varchar (  50 )                                     /*  80 出力ﾌｧｲﾙ名   */
 , COMMENTS     varchar ( 500 )                                     /*  90 ｺﾒﾝﾄ         */
 , SUDATA       INTEGER             DEFAULT 0   NOT NULL            /* 100 ﾃﾞｰﾀ件数     */
 , SUPAGE       INTEGER             DEFAULT 0   NOT NULL            /* 110 ﾍﾟｰｼﾞ数      */
 , DMN_NAME     varchar (  20 )                                     /* 120 更新ﾃﾞｰﾓﾝ名  */
 , DMN_HOST     varchar (  50 )                                     /* 130 ﾃﾞｰﾓﾝﾎｽﾄ     */
 , PDF_PASSWD   varchar (  20 )                                     /* 140 PDFﾊﾟｽﾜｰﾄﾞ   */
 , FGJ          varchar (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar (  14 )                                     /* 820 登録日時     */
 , PGSET        varchar (  10 )                                     /* 830 作成PG       */
 , PGPSET       varchar (  10 )                                     /* 840 作成親PG     */
 , USRSET       varchar (  10 )                                     /* 850 作成社員     */
 , DYUPD        varchar (  14 )                                     /* 860 更新日時     */
 , PGUPD        varchar (  10 )                                     /* 870 更新PG       */
 , PGPUPD       varchar (  10 )                                     /* 880 更新親PG     */
 , USRUPD       varchar (  10 )                                     /* 890 更新者       */
);

==> openGion7.0.2.3_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE50S.sql <==
/****************************************************************************/
/* GE50 ( 帳票要求ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE50 (
   SYSTEM_ID    varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , YKNO         INTEGER             DEFAULT 0   NOT NULL            /*  20 要求NO       */
 , GROUPID      varchar (  10 )                                     /*  30 ｸﾞﾙｰﾌﾟID     */
 , LISTID       varchar (  10 )                 NOT NULL            /*  40 帳票ID       */
 , JOKEN        varchar (  20 )                 NOT NULL            /*  50 振分条件     */
 , FGKAN        varchar (   1 )                 NOT NULL            /*  60 完成ﾌﾗｸﾞ     */
 , OUT_DIR      varchar ( 100 )                                     /*  70 出力ﾌｧｲﾙDIR  */
 , OUT_FILE     varchar (  50 )                                     /*  80 出力ﾌｧｲﾙ名   */
 , COMMENTS     varchar ( 500 )                                     /*  90 ｺﾒﾝﾄ         */
 , SUDATA       INTEGER             DEFAULT 0   NOT NULL            /* 100 ﾃﾞｰﾀ件数     */
 , SUPAGE       INTEGER             DEFAULT 0   NOT NULL            /* 110 ﾍﾟｰｼﾞ数      */
 , DMN_NAME     varchar (  20 )                                     /* 120 更新ﾃﾞｰﾓﾝ名  */
 , DMN_HOST     varchar (  50 )                                     /* 130 ﾃﾞｰﾓﾝﾎｽﾄ     */
 , PDF_PASSWD   varchar (  20 )                                     /* 140 PDFﾊﾟｽﾜｰﾄﾞ   */
 , FGJ          varchar (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar (  14 )                                     /* 820 登録日時     */
 , PGSET        varchar (  10 )                                     /* 830 作成PG       */
 , PGPSET       varchar (  10 )                                     /* 840 作成親PG     */
 , USRSET       varchar (  10 )                                     /* 850 作成者       */
 , DYUPD        varchar (  14 )                                     /* 860 更新日時     */
 , PGUPD        varchar (  10 )                                     /* 870 更新PG       */
 , PGPUPD       varchar (  10 )                                     /* 880 更新親PG     */
 , USRUPD       varchar (  10 )                                     /* 890 更新者       */
);
